==> niralanlayout-0.0.6.tar.gz: lib/ads_initialization/ads_initialization.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';

class AdsInitialization {
  static String bannerId = "";
  static String interstitialId = "";
  static String rewardId = "";
  static bool isLoadInterstitial = false;
  static InterstitialAd? interstitialAd;
  static bool isLoadRewardAd = false;
  static RewardedInterstitialAd? rewardAd;
  static num rewardPoint = 0;
  static int elapsedTime = 5;
  static bool isShowRewardAd = false;
  static bool isRemainMove = false;

  static initialization() {
    MobileAds.instance.initialize();
  }

  static isAndroid() {
    bool isResult = false;
    try {
      if (kIsWeb) {
        isResult = false;
      } else {
        if (kDebugMode) {
          isResult = true;
        } else {
          isResult = true;
        }
      }
    } catch (e) {
      isResult = false;
    }
    return isResult;
  }

  static DateTime previewsDateTime = DateTime.now();
  static int maxElapsedTime = 10;
  static bool isReachedElapsedTime() {
    bool result = false;
    DateTime to = DateTime.now();
    Duration difference = previewsDateTime.difference(to);
    if (maxElapsedTime <= difference.inSeconds.abs()) {
      result = true;
      previewsDateTime = DateTime.now();
    }
    return result;
  }

  static const AdRequest request = AdRequest(
    nonPersonalizedAds: true,
  );

  static void initInterstitial() {
    if (AdsInitialization.isAndroid() == true &&
        AdsInitialization.interstitialAd == null) {
      InterstitialAd.load(
        adUnitId: AdsInitialization.interstitialId,
        request: AdsInitialization.request,
        adLoadCallback: InterstitialAdLoadCallback(
          onAdLoaded: (InterstitialAd ad) {
            AdsInitialization.interstitialAd = ad;
            AdsInitialization.isLoadInterstitial = true;
          },
          onAdFailedToLoad: (LoadAdError error) {
            AdsInitialization.interstitialAd = null;
            AdsInitialization.isLoadInterstitial = false;
          },
        ),
      );
    }
  }

  static void getInterstitial() {
    if (AdsInitialization.isAndroid() == true) {
      if (AdsInitialization.interstitialAd != null) {
        AdsInitialization.interstitialAd!.show();
        AdsInitialization.interstitialAd!.fullScreenContentCallback =
            FullScreenContentCallback(
          onAdDismissedFullScreenContent: (InterstitialAd ad) {
            ad.dispose();
            if (AdsInitialization.interstitialAd != null) {
              AdsInitialization.interstitialAd!.dispose();
            }
            AdsInitialization.interstitialAd = null;
            AdsInitialization.isLoadInterstitial = false;
            AdsInitialization.initInterstitial();
          },
          onAdFailedToShowFullScreenContent:
              (InterstitialAd ad, AdError error) {
            ad.dispose();
            if (AdsInitialization.interstitialAd != null) {
              AdsInitialization.interstitialAd!.dispose();
            }
            AdsInitialization.interstitialAd = null;
            AdsInitialization.isLoadInterstitial = false;
            AdsInitialization.initInterstitial();
          },
        );
      }
    }
  }

  static void initRewardedInterstitialAd() {
    if (AdsInitialization.isAndroid() == true &&
        AdsInitialization.rewardAd == null) {
      RewardedInterstitialAd.load(
        adUnitId: AdsInitialization.rewardId,
        request: AdsInitialization.request,
        rewardedInterstitialAdLoadCallback: RewardedInterstitialAdLoadCallback(
          onAdLoaded: (RewardedInterstitialAd ad) {
            AdsInitialization.rewardAd = ad;
            AdsInitialization.isLoadRewardAd = true;
          },
          onAdFailedToLoad: (LoadAdError error) {
            AdsInitialization.rewardAd = null;
            AdsInitialization.isLoadRewardAd = false;
          },
        ),
      );
    }
  }

  static void rewardCallBack(num points) {
    if (points != 0) {
      AdsInitialization.rewardPoint = points;
    }
  }

  static void adCloseCallBack(
      String status, final Function(bool isRestartAudio) onCallBack) {
    if (status == 'SUCCESS' && AdsInitialization.rewardPoint != 0) {
      if (AdsInitialization.isRemainMove) {
        onCallBack(false);
      } else {
        onCallBack(true);
      }
    }
    AdsInitialization.rewardPoint = 0;
  }

  static void getRewardedInterstitial(
    final Function(bool isRestartAudio) onCallBack,
  ) {
    if (AdsInitialization.isAndroid() == true) {
      if (AdsInitialization.rewardAd != null) {
        AdsInitialization.rewardAd!.fullScreenContentCallback =
            FullScreenContentCallback(
          onAdShowedFullScreenContent: (RewardedInterstitialAd ad) {},
          onAdDismissedFullScreenContent: (RewardedInterstitialAd ad) {
            ad.dispose();
            adCloseCallBack('SUCCESS', onCallBack);
          },
          onAdFailedToShowFullScreenContent:
              (RewardedInterstitialAd ad, AdError error) {
            ad.dispose();
            adCloseCallBack('FAIL', onCallBack);
          },
        );
        AdsInitialization.rewardAd!.setImmersiveMode(true);
        AdsInitialization.rewardAd!.show(
          onUserEarnedReward: (AdWithoutView ad, RewardItem reward) {
            AdsInitialization.rewardCallBack(reward.amount);
          },
        );
        AdsInitialization.rewardAd = null;
        AdsInitialization.initRewardedInterstitialAd();
      } else {
        onCallBack(true);
      }
    } else {
      onCallBack(true);
    }
  }

  static BannerAd initBannerAd(
    Function onAdLoaded,
    Function onAdFailedToLoad,
  ) {
    return BannerAd(
      adUnitId: AdsInitialization.bannerId,
      size: AdSize.fullBanner,
      request: const AdRequest(),
      listener: BannerAdListener(
        onAdLoaded: (_) {
          onAdLoaded();
        },
        onAdFailedToLoad: (ad, error) {
          ad.dispose();
          onAdFailedToLoad();
        },
      ),
    )..load();
  }

  static Widget getBannerAds(BannerAd bannerAd, double width) {
    return StatefulBuilder(
      builder: (context, setState) => Container(
        height: bannerAd.size.height.toDouble(),
        width: width,
        alignment: Alignment.center,
        child: AdWidget(ad: bannerAd),
      ),
    );
  }
}

==> niralanlayout-0.1.2.tar.gz: lib/ads_initialization/ads_initialization.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';

class AdsInitialization {
  static String bannerId = "";
  static String interstitialId = "";
  static String rewardId = "";
  static bool isShowBanner = false;
  static bool isShowInterstitial = false;
  static bool isShowReward = false;

  static bool isLoadInterstitial = false;
  static InterstitialAd? interstitialAd;
  static bool isLoadRewardAd = false;
  static RewardedInterstitialAd? rewardAd;
  static num rewardPoint = 0;
  static int elapsedTime = 5;
  static bool isShowRewardAd = false;
  static bool isRemainMove = false;

  static initialization() {
    MobileAds.instance.initialize();
  }

  static isAndroid() {
    bool isResult = false;
    try {
      if (kIsWeb) {
        isResult = false;
      } else {
        if (kDebugMode) {
          isResult = true;
        } else {
          isResult = true;
        }
      }
    } catch (e) {
      isResult = false;
    }
    return isResult;
  }

  static DateTime previewsDateTime = DateTime.now();
  static int maxElapsedTime = 10;
  static bool isReachedElapsedTime() {
    bool result = false;
    DateTime to = DateTime.now();
    Duration difference = previewsDateTime.difference(to);
    if (maxElapsedTime <= difference.inSeconds.abs()) {
      result = true;
      previewsDateTime = DateTime.now();
    }
    return result;
  }

  static const AdRequest request = AdRequest(
    nonPersonalizedAds: true,
  );

  static void initInterstitial() {
    if (AdsInitialization.isAndroid() == true &&
        AdsInitialization.interstitialAd == null &&
        isShowInterstitial == true) {
      InterstitialAd.load(
        adUnitId: AdsInitialization.interstitialId,
        request: AdsInitialization.request,
        adLoadCallback: InterstitialAdLoadCallback(
          onAdLoaded: (InterstitialAd ad) {
            AdsInitialization.interstitialAd = ad;
            AdsInitialization.isLoadInterstitial = true;
          },
          onAdFailedToLoad: (LoadAdError error) {
            AdsInitialization.interstitialAd = null;
            AdsInitialization.isLoadInterstitial = false;
          },
        ),
      );
    }
  }

  static void getInterstitial() {
    if (AdsInitialization.isAndroid() == true) {
      if (AdsInitialization.interstitialAd != null) {
        AdsInitialization.interstitialAd!.show();
        AdsInitialization.interstitialAd!.fullScreenContentCallback =
            FullScreenContentCallback(
          onAdDismissedFullScreenContent: (InterstitialAd ad) {
            ad.dispose();
            if (AdsInitialization.interstitialAd != null) {
              AdsInitialization.interstitialAd!.dispose();
            }
            AdsInitialization.interstitialAd = null;
            AdsInitialization.isLoadInterstitial = false;
            AdsInitialization.initInterstitial();
          },
          onAdFailedToShowFullScreenContent:
              (InterstitialAd ad, AdError error) {
            ad.dispose();
            if (AdsInitialization.interstitialAd != null) {
              AdsInitialization.interstitialAd!.dispose();
            }
            AdsInitialization.interstitialAd = null;
            AdsInitialization.isLoadInterstitial = false;
            AdsInitialization.initInterstitial();
          },
        );
      }
    }
  }

  static void initRewardedInterstitialAd() {
    if (AdsInitialization.isAndroid() == true &&
        AdsInitialization.rewardAd == null &&
        isShowReward == true) {
      RewardedInterstitialAd.load(
        adUnitId: AdsInitialization.rewardId,
        request: AdsInitialization.request,
        rewardedInterstitialAdLoadCallback: RewardedInterstitialAdLoadCallback(
          onAdLoaded: (RewardedInterstitialAd ad) {
            AdsInitialization.rewardAd = ad;
            AdsInitialization.isLoadRewardAd = true;
          },
          onAdFailedToLoad: (LoadAdError error) {
            AdsInitialization.rewardAd = null;
            AdsInitialization.isLoadRewardAd = false;
          },
        ),
      );
    }
  }

  static void rewardCallBack(num points) {
    if (points != 0) {
      AdsInitialization.rewardPoint = points;
    }
  }

  static void adCloseCallBack(
      String status, final Function(bool isRestartAudio) onCallBack) {
    if (status == 'SUCCESS' && AdsInitialization.rewardPoint != 0) {
      if (AdsInitialization.isRemainMove) {
        onCallBack(false);
      } else {
        onCallBack(true);
      }
    }
    AdsInitialization.rewardPoint = 0;
  }

  static void getRewardedInterstitial(
    final Function(bool isRestartAudio) onCallBack,
  ) {
    if (AdsInitialization.isAndroid() == true) {
      if (AdsInitialization.rewardAd != null) {
        AdsInitialization.rewardAd!.fullScreenContentCallback =
            FullScreenContentCallback(
          onAdShowedFullScreenContent: (RewardedInterstitialAd ad) {},
          onAdDismissedFullScreenContent: (RewardedInterstitialAd ad) {
            ad.dispose();
            adCloseCallBack('SUCCESS', onCallBack);
          },
          onAdFailedToShowFullScreenContent:
              (RewardedInterstitialAd ad, AdError error) {
            ad.dispose();
            adCloseCallBack('FAIL', onCallBack);
          },
        );
        AdsInitialization.rewardAd!.setImmersiveMode(true);
        AdsInitialization.rewardAd!.show(
          onUserEarnedReward: (AdWithoutView ad, RewardItem reward) {
            AdsInitialization.rewardCallBack(reward.amount);
          },
        );
        AdsInitialization.rewardAd = null;
        AdsInitialization.initRewardedInterstitialAd();
      } else {
        onCallBack(true);
      }
    } else {
      onCallBack(true);
    }
  }

  static BannerAd? initBannerAd(
    Function onAdLoaded,
    Function onAdFailedToLoad,
  ) {
    if (isShowBanner == true) {
      return BannerAd(
        adUnitId: AdsInitialization.bannerId,
        size: AdSize.fullBanner,
        request: const AdRequest(),
        listener: BannerAdListener(
          onAdLoaded: (_) {
            onAdLoaded();
          },
          onAdFailedToLoad: (ad, error) {
            ad.dispose();
            onAdFailedToLoad();
          },
        ),
      )..load();
    } else {
      return null;
    }
  }

  static Widget getBannerAds(BannerAd bannerAd, double width) {
    return StatefulBuilder(
      builder: (context, setState) => Container(
        height: bannerAd.size.height.toDouble(),
        width: width,
        alignment: Alignment.center,
        child: AdWidget(ad: bannerAd),
      ),
    );
  }
}
